@@ -153,6 +153,8 @@ void ApplicationViewWidget::infoButtonClicked(Application *app)
     m_detailsView->setApplication(app);
     m_currentPair.first = m_detailsView;
 
+    connect(m_detailsView, SIGNAL(installButtonClicked(Application*)),
+            this, SLOT(installButtonClicked(Application*)));
     connect(m_detailsView, SIGNAL(installButtonClicked(Application *, const QHash<QApt::Package *, QApt::Package::State> &)),
             this, SLOT(installButtonClicked(Application *, const QHash<QApt::Package *, QApt::Package::State> &)));
     connect(m_detailsView, SIGNAL(removeButtonClicked(Application *)),
