@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright © 2009-2011 Jonathan Thomas <echidnaman@kubuntu.org>        *
+ *   Copyright © 2009 Jonathan Thomas <echidnaman@kubuntu.org>             *
  *   Copyright © 2009 Harald Sitter <apachelogger@ubuntu.com>              *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or         *
@@ -50,7 +50,7 @@ MuonNotifier::MuonNotifier(QObject* parent, const QList<QVariant>&)
 {
     KAboutData aboutData("muon-notifier", "muon-notifier",
                          ki18n("Muon Notification Daemon"),
-                         "1.1.2", ki18n("A Notification Daemon for Muon"),
+                         "1.2", ki18n("A Notification Daemon for Muon"),
                          KAboutData::License_GPL,
                          ki18n("(C) 2009-2011 Jonathan Thomas, (C) 2009 Harald Sitter"),
                          KLocalizedString(), "http://kubuntu.org");
