@@ -317,6 +317,7 @@ void PackageWidget::contextMenuRequested(const QPoint &pos)
             m_reinstallAction->setEnabled(false);
             m_keepAction->setEnabled(false);
         } else {
+            m_purgeAction->setEnabled(false);
             m_installAction->setEnabled(true);
             m_removeAction->setEnabled(false);
             m_upgradeAction->setEnabled(false);
@@ -419,6 +420,8 @@ void PackageWidget::actOnPackages(QApt::Package::State action)
 
     foreach (QApt::Package *package, packages) {
         if (m_stop) {
+            m_compressEvents = false;
+            QApplication::restoreOverrideCursor();
             break;
         }
 
